# kukiapipy
An Unofficial Python API Library to Chatbot for FREE...

## Chatbot Setup 

```py

import kukiapi

from kukiapi import kuki

aibot = kuki.chatbot(key='@kukiaichat contact get key', name='pranav', owner='moezilla', msg='hi')

print(aibot)

```


